@@ -56,13 +56,13 @@ class AppBuildCommand(CliCommand):
         parser.add_argument('--skip-docker-build', '-s', help='Do not execute docker build step. Just package.')
 
     def run(self, args):
-        ensure_docker()
+        compose_cmd = ensure_docker()
         ensure_mender_artifact(self._mender_artifact_path)
 
         self._temp_dir = tempfile.mkdtemp()
         meta = self._load_metadata(args)
 
-        image_path = self._generate_image(args, meta)
+        image_path = self._generate_image(compose_cmd, args, meta)
 
         if re.match('^v\d+$', meta['auterion-app-base']):
             v = meta['auterion-app-base']
@@ -102,8 +102,8 @@ class AppBuildCommand(CliCommand):
 
     def _compose_for_building_from_meta(self, meta):
         api_version = meta['auterion-api-version']
-        assert(0 <= api_version <= 1, f'Auterion API version {api_version} is not supported by this '
-                                      f'version of auterion-cli. Supported API versions are 0 and 1.')
+        assert 0 <= api_version <= 2, f'Auterion API version {api_version} is not supported by this ' \
+                                      f'version of auterion-cli. Supported API versions are 0 to 2.'
 
         compose = {}
         if api_version == 0:
@@ -111,7 +111,7 @@ class AppBuildCommand(CliCommand):
                 'version': '3.7',
                 **meta['compose']
             }
-        elif api_version == 1:
+        elif api_version >= 1:
             compose = {
                 'version': '3.7',
                 'services': {}
@@ -134,7 +134,7 @@ class AppBuildCommand(CliCommand):
             service['platform'] = PLATFORM_ALIAS.get(meta['target-platform'], meta['target-platform'])
         return compose
 
-    def _generate_image(self, args, meta):
+    def _generate_image(self, compose_cmd, args, meta):
         # Generate build dir
         project_dir = args.project_dir
         build_dir = os.path.join(project_dir, 'build')
@@ -144,7 +144,8 @@ class AppBuildCommand(CliCommand):
         target_file = os.path.join(build_dir, meta['app-name'] + '.tar')
 
         # generate a minimal docker-compose file in temp dir for building using docker-compose
-        compose_file = os.path.join(self._temp_dir, 'docker-compose.yml')
+        # (don't use self._temp_dir, as podman-compose sets cwd to that directory)
+        compose_file = 'docker-compose-tmp.yml'
         compose = self._compose_for_building_from_meta(meta)
         with open(compose_file, 'w') as f:
             yaml.dump(compose, f)
@@ -152,7 +153,9 @@ class AppBuildCommand(CliCommand):
         if not args.skip_docker_build:
             # Just export the required images from the local docker
             target_platform = PLATFORM_ALIAS.get(meta['target-platform'], meta['target-platform'])
-            run_command(['docker', 'compose', '-f', compose_file, 'build'], cwd=args.project_dir)
+            run_command(compose_cmd + ['-f', compose_file, 'build'], cwd=args.project_dir)
+
+            os.remove(compose_file)
 
             non_built_images = [v['image'] for k, v in compose['services'].items() if 'build' not in v]
             if len(non_built_images) > 0:
@@ -166,6 +169,8 @@ class AppBuildCommand(CliCommand):
             print(f'- {image}')
 
         print('Packaging those images...')
+        if os.path.isfile(target_file):
+            os.remove(target_file)
         run_command(['docker', 'save'] + images + ['-o', target_file], cwd=project_dir)
 
         return target_file
@@ -190,6 +195,8 @@ class AppBuildCommand(CliCommand):
                 service['volumes'] = [f'/data/app/{meta["app-name"]}/data:/data']
             if 'environment' not in service:
                 service['environment'] = ['PYTHONUNBUFFERED=1']
+            if 'env_file' not in service:
+                service['env_file'] = ['settings.default.env', 'settings.user.env']
 
             # older docker-compose get confused about the platform and build tags
             if 'platform' in service:
@@ -212,13 +219,27 @@ class AppBuildCommand(CliCommand):
         meta_file = os.path.join(args.project_dir, 'auterion-app.yml')
 
         version_file = os.path.join(self._temp_dir, 'version')
-        settings_file = os.path.join(self._temp_dir, 'settings.default.yml')
-        app_file = os.path.join(self._temp_dir, 'app.yml')
+        settings_file = os.path.join(args.project_dir, 'settings.default.env')
+
+        if not os.path.exists(settings_file):
+            settings_file = os.path.join(self._temp_dir, 'settings.default.env')
+            # create empty file
+            pathlib.Path(settings_file).touch()
 
         with open(version_file, 'w') as f:
             f.write(version)
 
-        self._generate_legacy_app_file(meta, app_file)
+        file_args = [
+            '-f', meta_file,
+            '-f', image_file,
+            '-f', version_file,
+            '-f', settings_file
+        ]
+
+        if meta['auterion-api-version'] < 2:
+            app_file = os.path.join(self._temp_dir, 'app.yml')
+            self._generate_legacy_app_file(meta, app_file)
+            file_args += ['-f', app_file]
 
         pathlib.Path(settings_file).touch()
 
@@ -231,11 +252,6 @@ class AppBuildCommand(CliCommand):
             '--software-filesystem', 'docker-app',
             '--software-name', name,
             '--software-version', version,
-            '-f', app_file,
-            '-f', version_file,
-            '-f', image_file,
-            '-f', settings_file,
-            '-f', meta_file
-        ])
+        ] + file_args)
 
 
