@@ -63,12 +63,16 @@ def _find_devices_address(addresses):
             pass
     return devices
 
-def _find_devices():
+
+def _find_devices(additional_ip_candidates=None):
+    candidates = ['127.0.0.1', '10.41.1.1', '10.41.2.1'] + additional_ip_candidates \
+        if additional_ip_candidates is not None else []
     devices = {}
-    devices.update(_find_devices_address(['10.41.1.1', '10.41.2.1']))
+    devices.update(_find_devices_address(candidates))
     devices.update(_find_devices_zeroconf(1))
     return devices
 
+
 class DeviceCommand(CliCommand):
     @staticmethod
     def help():
@@ -115,7 +119,7 @@ class DeviceCommand(CliCommand):
         print('      Use \'device deselect\' command to reset selection')
 
     def select(self, args):
-        devices = _find_devices()
+        devices = _find_devices([args.ip] if args.ip else [])
         serial = args.serial
 
         if serial not in devices:
