@@ -1,5 +1,6 @@
 import requests
 from .command_base import CliCommand
+from .utils import download_file, error
 
 
 class ReportCommand(CliCommand):
@@ -17,6 +18,12 @@ class ReportCommand(CliCommand):
         report_name = args.output
         if not report_name.endswith(".zip"):
             report_name += ".zip"
-        print(f"Downloading report to {report_name}")
-        r = requests.get(f"{self._sysinfo_api_endpoint}/report")
-        open(report_name, 'wb').write(r.content)
+        print("Generating report... This may take a few minutes")
+        print(f"Report will be downloaded to {report_name}")
+        download_file(f"{self._sysinfo_api_endpoint}/report", report_name)
+
+    def handle_exception(self, exception):
+        try:
+            raise exception
+        except requests.ConnectionError:
+            error(f"Could not connect to device.")
